<?php
/*
Plugin Name: WP Content Copy Protection with Color Design
Plugin URI: https://global-s-h.com/wp_protect/en/
Description: This plugin wll protect the posts content from copying by disable right click and disable selecting text. You can exclude pages. It also keeps from dragging images.  The message window can change color design.
Author: Kazuki Yanamoto
Version: 1.2.3
License: GPLv2 or later
Text Domain: wp-copy-protect-with-color-design
Domain Path: /languages/
*/

class CopyProtect
{
    public $textdomain = 'wp-copy-protect-with-color-design';
    public $plugins_url = '';

    public function __construct()
    {
        // プラグインが有効化された時
        if (function_exists('register_activation_hook')) {
            register_activation_hook(__FILE__, array($this, 'activationHook'));
        }
        //無効化
        if (function_exists('register_deactivation_hook')) {
            register_deactivation_hook(__FILE__, array($this, 'deactivationHook'));
        }
        //アンインストール
        if (function_exists('register_uninstall_hook')) {
            register_uninstall_hook(__FILE__, array($this, 'uninstallHook'));
        }

        //header()のフック
        //style/jQueryのリンク
        	add_action('wp_head', array($this, 'filter_header'));

			function protect_css_add(){
				wp_enqueue_script( 'jquery' );
				wp_enqueue_style( 'protect-link-css',plugins_url('/css/protect_style.css',__FILE__), array());
			}
				add_action('wp_enqueue_scripts','protect_css_add');

       //footer()のフッック
        add_filter('wp_footer', array($this, 'filter_footer'));

        //init
        add_action('init', array($this, 'init'));

        //ローカライズ
        add_action('init', array($this, 'load_textdomain'));

        //管理画面について
        add_action('admin_menu', array($this, 'protect_admin_menu'));

		//カラーピッカー
		function admin_scripts( $hook ) {

	        //wpcolor-pickerの指定
	        wp_enqueue_style( 'wp-color-picker' );

	        //外部JSファイルの指定
	        wp_enqueue_script( 'copy_colorpicker_script',plugins_url( '/js/Copy_colorPicker.js', __FILE__ ),array( 'wp-color-picker' ), false, true );
		}
		add_action( 'admin_enqueue_scripts', 'admin_scripts' );

    }


    /**
     * init
     */
     public function init()
     {
         $this->plugins_url = untrailingslashit(plugins_url('', __FILE__));
     }


    /***
     * ローカライズ
    ***/
    public function load_textdomain()
    {
        load_plugin_textdomain($this->textdomain, false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }


    /**
     * プラグインが有効化された時
     *
     */
    public function activationHook()
    {
        //オプションを初期値

		//右クリックした時（デフォルトはメッセージあり）
        if (! get_option('protect_plugin_value_click')) {
            update_option('protect_plugin_value_click', 2);
        }

        //右クリックした時（デフォルトのメッセージ）
        if (! get_option('protect_plugin_value_subject')) {
            update_option('protect_plugin_value_subject', __('Don`t copy text!', $this->textdomain));
        }

        //基本バックカラー
        if (! get_option('protect_plugin_value_color')) {
            update_option('protect_plugin_value_color', '#000000');
        }
 
		//ユーザー（デフォルトはadminは除く）
        if (! get_option('protect_plugin_value_user')) {
            update_option('protect_plugin_value_user', true);
        }
    }


    /***
     * 無効化時に実行
    ***/
    public function deactivationHook()
    {
        delete_option('protect_plugin_value_click');
        delete_option('protect_plugin_value_subject');
        delete_option('protect_plugin_value_color');
        delete_option('protect_plugin_value_user');
		delete_option('protect_plugin_value_pages');
    }


    /***
     * アンインストール時
    ***/
    public function uninstallHook()
    {
        delete_option('protect_plugin_value_click');
        delete_option('protect_plugin_value_subject');
        delete_option('protect_plugin_value_color');
        delete_option('protect_plugin_value_user');
		delete_option('protect_plugin_value_pages');
    }


    /***
     * 管理画面
    ***/
    public function protect_admin_menu()
    {
        add_options_page(
            'WP Copy Protection with Color Design', 
            __('WP Protect setting', $this->textdomain), 
            'manage_options',
            'WP_Copy_Protection_admin_menu',
            array($this, 'protect_edit_setting')
        );
    }


    /***
     * 管理画面を表示
    ***/
    public function protect_edit_setting()
    {
        // Include the settings page
        include(sprintf("%s/manage/admin.php", dirname(__FILE__)));
    }


    /***
     * idのページを省く
    ***/
	public function protect_excluded() {
		
		$excluded_id = explode(',', get_option('protect_plugin_value_pages'));
		
		if(is_array($excluded_id)) {
			
			foreach($excluded_id as $pages_id) {
				
				if(null != $pages_id && is_page($pages_id)) {
					
					return true;
				}
			}
		}
		
		return false;
	}

    /***
     * head部分にjquery
    ***/
	public function filter_header()
	{

		// アラートバックのカラー
	?>
		
		<script type="text/javascript">
			jQuery(function($){
				$('.protect_contents-overlay').css('background-color', '<?php echo esc_js(get_option('protect_plugin_value_color')); ?>');
			});
		</script>

		
		<?php
		
		// idページだったら
		if(!$this->protect_excluded()){ 

			// 管理者だったら
	 		if(!is_user_logged_in() || get_option('protect_plugin_value_user') == false){ 
			?>
				<script type="text/javascript">
				jQuery(function($){
					$('img').attr('onmousedown', 'return false');
					$('img').attr('onselectstart','return false');
				    $(document).on('contextmenu',function(e){

							<?php if(get_option('protect_plugin_value_click') == 2){ ?>

								// ブラウザ全体を暗くする
								$('.protect_contents-overlay, .protect_alert').fadeIn();

								
								$('.protect_contents-overlay, .protect_alert').click(function(){	
									// ブラウザ全体を明るくする
									$('.protect_contents-overlay, .protect_alert').fadeOut();
								});
							<?php } ?>


				        return false;
				    });
				});
				</script>

				<style>
				* {
				   -ms-user-select: none; /* IE 10+ */
				   -moz-user-select: -moz-none;
				   -khtml-user-select: none;
				   -webkit-user-select: none;
				   user-select: none;
				   }

				   input,textarea,select,option {
				   -ms-user-select: auto; /* IE 10+ */
				   -moz-user-select: auto;
				   -khtml-user-select: auto;
				   -webkit-user-select: auto;
				   user-select: auto;
			       }
				</style>
				
				<?php if(get_option('wp_content_plus_btn_f12') == true){ ?>
					<script type="text/javascript">
						function keydown()
						{
							if(event.keyCode >=123){ 
							event.keyCode = 0;
							return false;
							}
						}
						window.document.onkeydown = keydown;


						function pageMove(evt) //for FireFox and Edge
						{
						  var kcode;
						  
						  if (document.all)  
						  {
						    kcode = event.keyCode;
						  }
						  else
						  {
						    kcode = evt.which;
						  }
						  
						  if ( kcode == 123 ) { 
						  	kcode = 0;
						  	return false;
						  }
						}

						document.onkeydown = pageMove;

					</script>
				<?php }  ?>

			<?php
			}
		}
	}


    /***
    * footerの処理
    ***/
    public function filter_footer()
    {
		echo '<div class="protect_contents-overlay"></div>';
		echo '<div class="protect_alert"><span class="protect_alert_word">';
		echo get_option('protect_plugin_value_subject') ;
		echo '</span></div>';
    }


}
$CopyProtect = new CopyProtect();
